Module mvc

Module mvc 

Traits

Resource
A REST-ish resource controller: implement this once for a type and get the five conventional CRUD routes (GET /x, GET /x/:id, POST /x, PUT /x/:id, DELETE /x/:id) wired up for free via resource.

Functions

resource
Mounts a Resource at path, wiring the five CRUD routes onto it.